Module: Pod::Downloader::Http::AnkerArExtensions
- Included in:
- Pod::Downloader::Http
- Defined in:
- lib/cocoapods_plugin.rb
Overview
Use prepend instead of alias_method to safely monkey-patch without infinite recursion when the plugin is loaded more than once.
Instance Method Summary collapse
Instance Method Details
#download_file(full_filename) ⇒ Object
15 16 17 18 19 20 21 |
# File 'lib/cocoapods_plugin.rb', line 15 def download_file(full_filename) if url.to_s.include?('codingcorp-cocoapods.pkg.coding.anker-in.com') CodingArUtil.download(url, full_filename) else super end end |
#should_flatten? ⇒ Boolean
23 24 25 26 27 28 29 30 31 32 33 34 |
# File 'lib/cocoapods_plugin.rb', line 23 def should_flatten? if .key?(:indexDownload) && [:indexDownload] == true true elsif url.to_s.include?('codingcorp-cocoapods.pkg.coding.anker-in.com') # For CODING-AR packages, preserve directory structure to maintain .xcframework layout # Use indexDownload: true in podspec if flattening is needed puts "🔧 [CocoaPods-Anker-AR] Preserving directory structure for CODING-AR package" false else super end end |